@@ -26,3 +26,19 @@ if (distutils.version.LooseVersion(astropy.__version__) <
         distutils.version.LooseVersion("3")):
     raise RuntimeError('pfsspy requires astropy v3 to run ' +
                        f'(found version {astropy.__version__} installed)')
+
+
+__citation__ = __bibtex__ = """
+@article{Stansby2020,
+doi = {10.21105/joss.02732},
+url = {https://doi.org/10.21105/joss.02732},
+year = {2020},
+publisher = {The Open Journal},
+volume = {5},
+number = {54},
+pages = {2732},
+author = {David Stansby and Anthony Yeates and Samuel T. Badman},
+title = {pfsspy: A Python package for potential field source surface modelling},
+journal = {Journal of Open Source Software}
+}
+"""
